import QtQuick 1.1
import com.nokia.meego 1.0
import playmee 1.0

Page {
    property alias model: listView.model
    tools: ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: pageStack.pop();
        }
        ToolIcon {
            platformIconId: "toolbar-mediacontrol-play"
            onClicked: pageStack.push(nowPlayingPage);
        }
    }


    ListView {
        id: listView
        anchors { left: parent.left; top: parent.top; right: parent.right; bottom: parent.bottom }
        anchors.leftMargin: 10
        anchors.rightMargin: 10

        header:     Rectangle {
            id: headerItem
            height: listView.model.hasHeaderDetails ? 150 : 0
            visible: height > 0
            anchors { left: parent.left; top: parent.top; right: parent.right }
            color: "black"
            z: 1
            Row {
                anchors.fill: parent
                //anchors.margins: 10
                spacing: 10
                Item {
                    id: headerImageItem
                    height: parent.height
                    width: height
                    DefaultFanart {
                        anchors.fill: parent
                        visible: headerImage.status !== Image.Ready
                        coverText: listView.model.modelTitle
                    }

                    Image {
                        id: headerImage
                        anchors.fill: parent
                        fillMode: Image.Stretch
                        source: listView.model.modelThumbnail
                    }
                }
                Column {
                    anchors.verticalCenter: parent.verticalCenter
                    width: parent.width - headerImageItem.width - parent.spacing
                    Label {
                        text: listView.model.modelTitle
                        font.pixelSize: 26
                        font.weight: Font.Bold
                        width: parent.width
                        elide: Text.ElideRight
                    }
                    Label {
                        text: listView.model.modelSubTitle
                        font.pixelSize: 24
                        width: parent.width
                        elide: Text.ElideRight
                    }
                }
            }
        }


        delegate: Rectangle {
            width: parent.width
            height: 88
            color: mouseArea.pressed ? "#333333" : "black"

            Row {
                height: parent.height - 4
                width: parent.width
                anchors.verticalCenter: parent.verticalCenter
                spacing: 10
                Item {
                    id: thumbnailImage
                    height: parent.height
                    width: height
                    visible: !listView.model.hasHeaderDetails //&& thumbnail.length > 0

                    DefaultFanart {
                        anchors.fill: parent
                        visible: tI.status !== Image.Ready || thumbnail.length === 0
                        coverText: title
                    }

                    Image {
                        id: tI
                        anchors.fill: parent
                        source: thumbnail
                        fillMode: Image.Stretch
                    }
                }

                Column {
                    anchors.verticalCenter: parent.verticalCenter
                    width: parent.width - (thumbnailImage.visible ? thumbnailImage.width + spacing: 0) - (arrow.visible ? arrow.width + spacing : 0) - parent.spacing*2

                    Label {
                        id: mainText
                        text: label
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        width: parent.width
                        elide: Text.ElideRight
                    }

                    Label {
                        id: subText
                        text: subtitle
                        font.weight: Font.Light
                        font.pixelSize: 24
                        color: theme.inverted ? "#7b797b" : "#848684"
                        width: parent.width
                        elide: Text.ElideRight
                        visible: text !== ""
                    }
                }
            }

//            BorderImage {
//                id: background
//                anchors.fill: parent
//                visible: mouseArea.pressed
//                source: "image://theme/meegotouch-list-background-pressed-center"
//            }

            MouseArea {
                id: mouseArea
                anchors.fill: parent
                onClicked: {
                    if(type === ModelItem.TypeDirectory) {
                        print("enering", url);
                        var newModel = listView.model.enterItem(index);
                        var component = Qt.createComponent("BrowserPage.qml");
                        pageStack.push(component, {model: newModel});
                    } else {
                        print("clearing...", core.playlist());
                        core.playlist().clear();

                        var itemToPlay = 0;
                        var addedItems = 0;
                        for (var i = 0; i < listView.count; ++i) {
                            if (listView.model.item(i).type === ModelItem.TypeFile) {
                                core.playlist().insertItem(listView.model.item(i));
                                if (i === index) {
                                    itemToPlay = addedItems;
                                }
                                addedItems++;
                            }
                        }
                        core.playlist().currentIndex = itemToPlay;
                        core.player().play();
                        pageStack.push(nowPlayingPage);
                    }
                }
            }

            Item {
                id: arrow
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right;
                width: visible ? durationLabel.width : 0
                Image {
                    id: arrowImage
                    source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                    anchors.right: parent.right;
                    anchors.verticalCenter: parent.verticalCenter
                    visible: type === ModelItem.TypeDirectory
                    opacity: .5
                }
                Label {
                    id: durationLabel
                    anchors.right: parent.right;
                    anchors.verticalCenter: parent.verticalCenter
                    visible: type === ModelItem.TypeFile
                    text: duration
                }
            }
        }
    }
}
