import QtQuick 1.1

PathView {
    id: myPathView
    height: itemHeight
    width: itemWidth
    preferredHighlightBegin: 0.5
    preferredHighlightEnd: 0.5
    pathItemCount: 2

    property int itemWidth: width
    property int itemHeight: height
    property int expadedWidth: width
    property int expandedHeight: height

    property alias model: myPathView.model


    delegate: Flipable {
        id: myFlipable

        property bool flipped: false

        width: flipped ? expadedWidth : itemWidth;
        height: flipped ? expandedHeight : itemHeight
        z: PathView.z
        scale: PathView.iconScale
        property double blabla: PathView.angle1

//            onBlablaChanged: print("!?!?", blabla)

//        function itemClicked()
//        {
//            myFlipable.flipped = !myFlipable.flipped
//            myPathView.interactive = !myFlipable.flipped
//        }

        Keys.onReturnPressed: itemClicked()

        MouseArea {
            anchors.fill: parent
            onClicked: itemClicked()
        }
        transform: Rotation {
            id: rotation
            origin.x: myFlipable.width/2
            origin.y: myFlipable.height/2
            axis.x: 0; axis.y: 1; axis.z: 0
            angle: myFlipable.blabla
        }

        states: State {
            name: "back"
            PropertyChanges { target: rotation; angle: 180 }
            PropertyChanges {target: myFlipable; width: myPathView.width; height: myPathView.height }
            when: myFlipable.flipped
        }

        transitions: Transition {
            ParallelAnimation {
                NumberAnimation { target: rotation; property: "angle"; duration: 250 }
                NumberAnimation {target: myFlipable; properties: "height,width"; duration: 250}
            }
        }

        front: Item {
            smooth: true
            width: itemWidth; height: itemHeight
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter

            DefaultFanart {
                anchors.fill: parent
                coverText: title
            }

            Image {
                id: myIcon
                anchors.fill: parent
                source: thumbnail
                smooth: true
            }
        }
        back: Rectangle {
            anchors.fill: parent
            color: "black"
        }
    }

    path: Path {
        startX: 0
        startY: myPathView.height / 2
        PathAttribute { name: "z"; value: 0 }
        PathAttribute { name: "angle1"; value: -90 }
        PathAttribute { name: "iconScale"; value: .81 }
        PathQuad { x: myPathView.width / 2; y: myPathView.height / 2; controlX: 5; controlY: myPathView.height / 2}
        PathAttribute { name: "z"; value: 100 }
        PathAttribute { name: "angle1"; value: 0 }
        PathAttribute { name: "iconScale"; value: 1.0 }
        PathQuad { x: myPathView.width; y: myPathView.height / 2; controlX: myPathView.width - 5; controlY: myPathView.height / 2}
        PathAttribute { name: "z"; value: 0 }
        PathAttribute { name: "angle1"; value: 90 }
        PathAttribute { name: "iconScale"; value: .81 }
    }
}
