import QtQuick 1.1
import com.nokia.meego 1.0
import playmee 1.0

Page {
    id: mainPage
    tools: nowPlayingToolbar
    property QtObject player: appWindow.core.player()
    property QtObject playlist: appWindow.core.playlist()
    property QtObject currentItem: playlist.item(playlist.currentIndex)

    property string orientation: width > height ? "landscape" : "portrait"

    Connections {
        target: playlist
        onCurrentIndexChanged: {
            imageItem.currentIndex = playlist.currentIndex;
        }
    }

    ToolBarLayout {
        id: nowPlayingToolbar
        ToolIcon { platformIconId: "toolbar-column";
            onClicked: {
                pageStack.pop()
            }
        }
        ToolIcon {
            iconSource: "icons/shuffle" + (playlist.playbackMode === Playlist.Random ? "-on" : "-off") + "-black.png"
            onClicked: {
                if( playlist.playbackMode === Playlist.Random ) {
                    playlist.playbackMode = Playlist.Sequential;
                } else {
                    playlist.playbackMode = Playlist.Random;
                }
            }
        }
        ToolIcon {
            iconSource: "icons/repeat" +
                        (playlist.playbackMode ===  Playlist.CurrentItemInLoop ? "-one" : (playlist.playbackMode === Playlist.Loop ? "-all" : "-none")) +
                        "-black.png"
            onClicked: {
                if( playlist.playbackMode === Playlist.CurrentItemInLoop ) {
                    playlist.playbackMode = Playlist.Sequential;
                } else if( playlist.playbackMode === Playlist.Loop ) {
                    playlist.playbackMode = Playlist.CurrentItemInLoop;
                } else {
                    playlist.playbackMode = Playlist.Loop;
                }
            }
        }
        ToolIcon { platformIconId: "toolbar-view-menu";
            onClicked: {
                var component = Qt.createComponent("PlaylistPage.qml")
                if (component.status === Component.Ready) {
                    pageStack.push(component);
                } else {
                    console.log("Error loading component:", component.errorString());
                }
            }
        }
    }

    Component.onCompleted: {
        console.log("player is " + player)
        console.log("playlist is " + playlist)
    }

    Grid {
        anchors.fill: parent
        columns: mainPage.orientation == "portrait" ? 1 : 2
        spacing: mainPage.orientation == "landscape" ? 10 : 0

        CoverCube {
            id: imageItem
            height: mainPage.orientation == "portrait" ? parent.width : parent.height
            width: mainPage.orientation == "portrait" ? parent.width : height
            model: playlist
            clip: mainPage.orientation == "landscape"

            onCurrentIndexChanged: {
                if(currentIndex !== playlist.currentIndex) {
                    playlist.currentIndex = currentIndex;
                }
            }
        }

//        Item {
//            id: imageItem
//            height: mainPage.orientation == "portrait" ? parent.width : parent.height
//            width: mainPage.orientation == "portrait" ? parent.width : height
//            //            Rectangle {
//            //                color: "blue"
//            //                anchors.fill: parent
//            //            }

//            DefaultFanart {
//                anchors.fill: parent
//                visible: thumbImage.status !== Image.Ready
//                coverText: currentItem.album
//            }

//            Image {
//                id: thumbImage
//                anchors.fill: parent
//                source: currentItem.thumbnail
//                fillMode: Image.PreserveAspectFit

//                onSourceChanged: print("thumbnail source is now:" + currentItem.thumbnail)
//            }
//        }

        Item {
            id: textItem
            width: mainPage.orientation == "portrait" ? parent.width : parent.width - imageItem.width - parent.spacing
            height: mainPage.orientation == "portrait" ? parent.height - imageItem.height - parent.spacing : parent.height
            Label {
                id: currentTime
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                text: player.time
            }

            Label {
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                text: player.durationString
            }

            ButtonRow {
                id: controlButtons
                anchors {left:parent.left; right: parent.right; bottom: progressBar.top }
                anchors.bottomMargin: 20
                spacing: (width - previousIcon.width * 3) / 2
                ToolIcon {
                    id: previousIcon
                    platformIconId: "toolbar-mediacontrol-previous"
                    onClicked: playlist.previous();
                }
                ToolIcon {
                    platformIconId: player.state === Player.PlayingState ? "toolbar-mediacontrol-pause" : "toolbar-mediacontrol-play"
                    onClicked: player.playPause();
                }
                ToolIcon { platformIconId: "toolbar-mediacontrol-next"
                    onClicked: playlist.next();
                }
            }

            ProgressBar {
                id: progressBar
                anchors { left: parent.left; right: parent.right; bottom: currentTime.top }
                anchors.bottomMargin: 10
                width: 300
                minimumValue: 0
                maximumValue: 100
                value: player.percentage

                Rectangle {
                    color: theme.inverted ? "white" : "black"
                    rotation: 45
                    width: 10
                    height: 10
                    anchors.horizontalCenter: progressBarLabel.horizontalCenter
                    anchors.verticalCenter: progressBarLabel.bottom
                    visible: progressBarLabel.visible
                }

                Rectangle {
                    id: progressBarLabel
                    color: theme.inverted ? "white" : "black"
                    anchors.bottom: parent.top
                    anchors.bottomMargin: 40
                    height: 40
                    width: progressBarLabelText.width + 20
                    radius: 5
                    visible: progressBarMouseArea.pressed

                    Label {
                        id: progressBarLabelText
                        anchors.centerIn: parent
                        color: theme.inverted ? "black" : "white"
                    }
                }

                MouseArea {
                    id: progressBarMouseArea
                    anchors.fill: progressBar
                    anchors.topMargin: -10
                    anchors.bottomMargin: -10

                    onMouseXChanged: {
                        // Center label on mouseX
                        progressBarLabel.x = mouseX - progressBarLabel.width / 2;

                        // Calculate time under mouseX
                        var progressedWidth = mouseX - progressBar.x;
                        var targetTime = progressedWidth * player.duration / 1000 / progressBar.width;
                        targetTime = Math.min(targetTime, player.duration / 1000);
                        targetTime = Math.max(targetTime, 0);

                        // Translate to human readable time
                        var hours = Math.floor(targetTime / 60 / 60);
                        var minutes = Math.floor(targetTime / 60) % 60;
                        if(minutes < 10) minutes = "0" + minutes;
                        var seconds = Math.floor(targetTime) % 60;
                        if(seconds < 10) seconds = "0" + seconds;

                        // Write into the label
                        if(player.duration / 1000 < 60 * 60) {
                            progressBarLabelText.text = minutes + ":" + seconds;
                        } else {
                            progressBarLabelText.text = hours + ":" + minutes + ":" + seconds;
                        }
                    }
                    onReleased: {
                        player.percentage = mouseX * 100 / width
                    }
                }
            }

            Row {
                id: albumRow
                anchors.bottom: controlButtons.top
                height: albumLabel.height
                anchors.left: parent.left
                anchors.bottomMargin: 10
                Label {
                    id: albumLabel
                    text: currentItem.album
                }
                property int starCount: currentItem.rating > 10 ? Math.floor(currentItem.rating / 20) : Math.floor(currentItem.rating / 2)
                Repeater {
                    model: parent.starCount
                    Image {
                        visible: currentItem.type === "movie"
                        source: theme.inverted ? "image://theme/meegotouch-indicator-rating-inverted-background-star" : "image://theme/meegotouch-indicator-rating-star"
                    }
                }
                Repeater {
                    model: 5 - parent.starCount
                    Image {
                        visible: currentItem.type === "movie"
                        source: theme.inverted ? "image://theme/meegotouch-indicator-rating-background-star" : "image://theme/meegotouch-indicator-rating-background-star"
                    }
                }
            }

            Label {
                id: artistLabel
                anchors.bottomMargin: 6
                anchors.left: parent.left
                anchors.bottom: albumRow.top
                anchors.right: infoButton.left
                text: currentItem.artist
            }
//            Button {
//                id: infoButton
//                text: "i"
//                width: height
//                anchors.top: trackNumLabel.bottom
//                anchors.right: parent.right

//                onClicked: {
//                    //listView.model.fetchItemDetails(listView.currentIndex)
//                    pageStack.push(Qt.createComponent(Qt.resolvedUrl("NowPlayingDetails.qml")));
//                }
//            }

            Label {
                id: trackLabel
                anchors.left: parent.left
                //anchors.right: trackNumLabel.right
                width: parent.width - trackNumLabel.width
                anchors.bottom: artistLabel.top
                anchors.bottomMargin: 6
                text: currentItem.title
                elide: Text.ElideRight
                font.bold: true
            }
            Label {
                id: trackNumLabel
                anchors.right: parent.right
                anchors.bottom: artistLabel.top
                anchors.bottomMargin: 6
                text: playlist.currentIndex + 1 + "/" + playlist.count
            }
        }
    }
}
